==> libsrcvdmtl-0.1.tar.gz: libsrcvdmtl-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'libsrcvdmtl',         # How you named your package folder (MyLib)
  packages = ['libsrcvdmtl'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Library using the src folder for the Premiers Repondants Project',   # Give a short description about your library
  author = 'broth',                   # Type in your name
  author_email = 'basile.roth@montreal.ca',      # Type in your E-Mail
  url = 'https://github.com/basileroth75/libsrcvdmtl',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/basileroth75/libsrcvdmtl/archive/v1.0.tar.gz',    # I explain this later on
  keywords = ['SRC', 'VDMTL', 'LIBRARY'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'sklearn',
          'dill',
          'requests',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> libsrcvdmtl-v1.1.tar.gz: libsrcvdmtl-v1.1/setup.py <==
from distutils.core import setup
setup(
  name = 'libsrcvdmtl',         # How you named your package folder (MyLib)
  packages = ['libsrcvdmtl'],   # Chose the same as "name"
  version = 'v1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Library using the src folder for the Premiers Repondants Project',   # Give a short description about your library
  author = 'broth',                   # Type in your name
  author_email = 'basile.roth@montreal.ca',      # Type in your E-Mail
  url = 'https://github.com/basileroth75/libsrcvdmtl',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/basileroth75/libsrcvdmtl/archive/v1.1.tar.gz',    # I explain this later on
  keywords = ['SRC', 'VDMTL', 'LIBRARY'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'sklearn',
          'dill',
          'pyflux',
          'requests',
          'multiprocessing',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
